/**
 * Select elements of DOM, return array of elements or element
 *
 * @param selector
 * @param parent
 * @returns {HTMLElement}
 */
const $ = (selector, parent = undefined) => {
    parent = (parent === undefined) ? document : parent;
    let elements = Array.from(parent.querySelectorAll(selector));

    return (elements.length === 1) ? elements[0] : elements;
}

/**
 * Select and modify elements of DOM
 *
 * @param selector
 * @param parent
 * @returns {HTMLElement}
 */
const $$ = (selector, parent = undefined) => {
    parent = (parent === undefined) ? document : parent;
    let elements = Array.from(parent.querySelectorAll(selector));

    return {
        elements,
        css: function (styles) {
            elements.forEach(el => {
                Object.assign(el.style, styles);
            });
            return this;
        },
        text: function (content) {
            elements.forEach(el => {
                el.textContent = content;
            });
            return this;
        },
        html: function (content) {
            elements.forEach(el => {
                el.innerHTML = content;
            });
            return this;
        },
        on: function (event, handler) {
            elements.forEach(el => {
                el.addEventListener(event, handler);
            });
            return this;
        }
    };
};